@@ -120,7 +120,7 @@ use Class::MethodMaker [
     )],
 ];
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my $_session_count = 0;
 
@@ -695,10 +695,8 @@ sub _next_recurse {
     return $stack->[$stack_index + 1][0];
 }
 
-sub next {
-    my $self = $_[OBJECT];
-
-    return if $self->pause_state || $self->is_finished;
+sub get_next_action {
+	my $self = shift;
 
     ## Find the next action to execute
 
@@ -714,6 +712,16 @@ sub next {
     # Store the newly changed action path
     $self->active_action_path(@active_action_path);
 
+	return $action;
+}
+
+sub next {
+    my $self = $_[OBJECT];
+
+    return if $self->pause_state || $self->is_finished;
+
+	my $action = $self->get_next_action();
+
     if (defined $action) {
         # Create request to pass to handlers
         my $request = {
